# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive_submission_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/interactive_submission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_commands__pb2
from . import interactive_submission_data_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_interactive__submission__data__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/daml/ledger/api/v2/interactive_submission_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a%com/daml/ledger/api/v2/commands.proto\x1a\x38\x63om/daml/ledger/api/v2/interactive_submission_data.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x04\n\x18PrepareSubmissionRequest\x12%\n\x0e\x61pplication_id\x18\x01 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12;\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x1f.com.daml.ledger.api.v2.CommandR\x08\x63ommands\x12I\n\x13min_ledger_time_abs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10minLedgerTimeAbs\x12H\n\x13min_ledger_time_rel\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10minLedgerTimeRel\x12\x15\n\x06\x61\x63t_as\x18\x06 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\x07 \x03(\tR\x06readAs\x12Z\n\x13\x64isclosed_contracts\x18\x08 \x03(\x0b\x32).com.daml.ledger.api.v2.DisclosedContractR\x12\x64isclosedContracts\x12\x1b\n\tdomain_id\x18\t \x01(\tR\x08\x64omainId\x12\x45\n\x1fpackage_id_selection_preference\x18\n \x03(\tR\x1cpackageIdSelectionPreference\"\xb7\x01\n\x19PrepareSubmissionResponse\x12^\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32+.com.daml.ledger.api.v2.PreparedTransactionR\x13preparedTransaction\x12:\n\x19prepared_transaction_hash\x18\x02 \x01(\x0cR\x17preparedTransactionHash\"\x87\x01\n\tSignature\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\'.com.daml.ledger.api.v2.SignatureFormatR\x06\x66ormat\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12\x1b\n\tsigned_by\x18\x03 \x01(\tR\x08signedBy\"p\n\x15SinglePartySignatures\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x41\n\nsignatures\x18\x02 \x03(\x0b\x32!.com.daml.ledger.api.v2.SignatureR\nsignatures\"`\n\x0fPartySignatures\x12M\n\nsignatures\x18\x01 \x03(\x0b\x32-.com.daml.ledger.api.v2.SinglePartySignaturesR\nsignatures\"\xe0\x03\n\x18\x45xecuteSubmissionRequest\x12^\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32+.com.daml.ledger.api.v2.PreparedTransactionR\x13preparedTransaction\x12V\n\x12parties_signatures\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v2.PartySignaturesR\x11partiesSignatures\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12R\n\x16\x64\x65\x64uplication_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x05 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12%\n\x0e\x61pplication_id\x18\x07 \x01(\tR\rapplicationIdB\x16\n\x14\x64\x65\x64uplication_period\"\x1b\n\x19\x45xecuteSubmissionResponse*M\n\x0fSignatureFormat\x12 \n\x1cSIGNATURE_FORMAT_UNSPECIFIED\x10\x00\x12\x18\n\x14SIGNATURE_FORMAT_RAW\x10\x01\x32\x92\x02\n\x1cInteractiveSubmissionService\x12x\n\x11PrepareSubmission\x12\x30.com.daml.ledger.api.v2.PrepareSubmissionRequest\x1a\x31.com.daml.ledger.api.v2.PrepareSubmissionResponse\x12x\n\x11\x45xecuteSubmission\x12\x30.com.daml.ledger.api.v2.ExecuteSubmissionRequest\x1a\x31.com.daml.ledger.api.v2.ExecuteSubmissionResponseB\xa0\x01\n\x16\x63om.daml.ledger.api.v2B&InteractiveSubmissionServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive_submission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B&InteractiveSubmissionServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_SIGNATUREFORMAT']._serialized_start=1846
  _globals['_SIGNATUREFORMAT']._serialized_end=1923
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_start=250
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_end=796
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_start=799
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_end=982
  _globals['_SIGNATURE']._serialized_start=985
  _globals['_SIGNATURE']._serialized_end=1120
  _globals['_SINGLEPARTYSIGNATURES']._serialized_start=1122
  _globals['_SINGLEPARTYSIGNATURES']._serialized_end=1234
  _globals['_PARTYSIGNATURES']._serialized_start=1236
  _globals['_PARTYSIGNATURES']._serialized_end=1332
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_start=1335
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_end=1815
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_start=1817
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_end=1844
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_start=1926
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_end=2200
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v1 import topology_pb2 as _topology_pb2
from . import domain_params_pb2 as _domain_params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DomainParametersChange(_message.Message):
    __slots__ = ("domain", "domain_parameters")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    domain_parameters: _domain_params_pb2.DynamicDomainParameters
    def __init__(self, domain: _Optional[str] = ..., domain_parameters: _Optional[_Union[_domain_params_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...

class DomainGovernanceTransaction(_message.Message):
    __slots__ = ("domain_parameters_change",)
    DOMAIN_PARAMETERS_CHANGE_FIELD_NUMBER: _ClassVar[int]
    domain_parameters_change: DomainParametersChange
    def __init__(self, domain_parameters_change: _Optional[_Union[DomainParametersChange, _Mapping]] = ...) -> None: ...

class TopologyTransaction(_message.Message):
    __slots__ = ("state_update", "domain_governance")
    STATE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
    state_update: _topology_pb2.TopologyStateUpdate
    domain_governance: DomainGovernanceTransaction
    def __init__(self, state_update: _Optional[_Union[_topology_pb2.TopologyStateUpdate, _Mapping]] = ..., domain_governance: _Optional[_Union[DomainGovernanceTransaction, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ObjectMeta(_message.Message):
    __slots__ = ("resource_version", "annotations")
    class AnnotationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    RESOURCE_VERSION_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    resource_version: str
    annotations: _containers.ScalarMap[str, str]
    def __init__(self, resource_version: _Optional[str] = ..., annotations: _Optional[_Mapping[str, str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/ordering_request.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/ordering_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/digitalasset/canton/protocol/v30/ordering_request.proto\x12$com.digitalasset.canton.protocol.v30\x1a\x1egoogle/protobuf/wrappers.proto\"m\n\x0fOrderingRequest\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x35\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\x07\x63ontentBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.ordering_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_ORDERINGREQUEST']._serialized_start=133
  _globals['_ORDERINGREQUEST']._serialized_end=242
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v0 import common_pb2 as _common_pb2
from ..v0 import mediator_pb2 as _mediator_pb2
from . import merkle_pb2 as _merkle_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionResultMessage(_message.Message):
    __slots__ = ("request_id", "verdict", "notification_tree")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_TREE_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    verdict: Verdict
    notification_tree: InformeeTree
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., verdict: _Optional[_Union[Verdict, _Mapping]] = ..., notification_tree: _Optional[_Union[InformeeTree, _Mapping]] = ...) -> None: ...

class Verdict(_message.Message):
    __slots__ = ("approve", "participant_reject", "mediator_reject")
    APPROVE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_REJECT_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_REJECT_FIELD_NUMBER: _ClassVar[int]
    approve: _empty_pb2.Empty
    participant_reject: ParticipantReject
    mediator_reject: MediatorReject
    def __init__(self, approve: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., participant_reject: _Optional[_Union[ParticipantReject, _Mapping]] = ..., mediator_reject: _Optional[_Union[MediatorReject, _Mapping]] = ...) -> None: ...

class InformeeTree(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: _merkle_pb2.GenTransactionTree
    def __init__(self, tree: _Optional[_Union[_merkle_pb2.GenTransactionTree, _Mapping]] = ...) -> None: ...

class ParticipantReject(_message.Message):
    __slots__ = ("reasons",)
    REASONS_FIELD_NUMBER: _ClassVar[int]
    reasons: _containers.RepeatedCompositeFieldContainer[_mediator_pb2.RejectionReason]
    def __init__(self, reasons: _Optional[_Iterable[_Union[_mediator_pb2.RejectionReason, _Mapping]]] = ...) -> None: ...

class MediatorReject(_message.Message):
    __slots__ = ("cause", "error_code", "error_category")
    CAUSE_FIELD_NUMBER: _ClassVar[int]
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_CATEGORY_FIELD_NUMBER: _ClassVar[int]
    cause: str
    error_code: str
    error_category: int
    def __init__(self, cause: _Optional[str] = ..., error_code: _Optional[str] = ..., error_category: _Optional[int] = ...) -> None: ...

class MalformedMediatorRequestResult(_message.Message):
    __slots__ = ("request_id", "domain_id", "view_type", "rejection")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    REJECTION_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    domain_id: str
    view_type: _common_pb2.ViewType
    rejection: MediatorReject
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ..., rejection: _Optional[_Union[MediatorReject, _Mapping]] = ...) -> None: ...

class TransferResult(_message.Message):
    __slots__ = ("request_id", "origin_domain", "target_domain", "informees", "verdict")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    origin_domain: str
    target_domain: str
    informees: _containers.RepeatedScalarFieldContainer[str]
    verdict: Verdict
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., origin_domain: _Optional[str] = ..., target_domain: _Optional[str] = ..., informees: _Optional[_Iterable[str]] = ..., verdict: _Optional[_Union[Verdict, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from ....admin.pruning.v30.pruning_pb2 import ClearSchedule, GetSchedule, LocatePruningTimestamp, SetCron, SetMaxDuration, SetRetention, SetSchedule
from .sequencer_pruning_administration_service_pb2 import SequencerPruning

__all__ = [
    "SequencerPruningAdministrationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerPruningAdministrationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerPruningAdministrationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerPruningAdministrationServiceAsyncStub: ...  # type: ignore
    def Prune(self, __1: SequencerPruning.PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerPruning.PruneResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerPruning.PruneResponse]]: ...
    def SetSchedule(self, __1: SetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetSchedule.Response]]: ...
    def SetCron(self, __1: SetCron.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetCron.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetCron.Response]]: ...
    def SetMaxDuration(self, __1: SetMaxDuration.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetMaxDuration.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDuration.Response]]: ...
    def SetRetention(self, __1: SetRetention.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetRetention.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetention.Response]]: ...
    def ClearSchedule(self, __1: ClearSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ClearSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, ClearSchedule.Response]]: ...
    def GetSchedule(self, __1: GetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetSchedule.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, GetSchedule.Response]]: ...
    def LocatePruningTimestamp(self, __1: LocatePruningTimestamp.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[LocatePruningTimestamp.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, LocatePruningTimestamp.Response]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerPruningAdministrationServiceBlockingStub(SequencerPruningAdministrationServiceStub):
    def Prune(self, __1: SequencerPruning.PruneRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerPruning.PruneResponse: ...
    def SetSchedule(self, __1: SetSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetSchedule.Response: ...
    def SetCron(self, __1: SetCron.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetCron.Response: ...
    def SetMaxDuration(self, __1: SetMaxDuration.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetMaxDuration.Response: ...
    def SetRetention(self, __1: SetRetention.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetRetention.Response: ...
    def ClearSchedule(self, __1: ClearSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ClearSchedule.Response: ...
    def GetSchedule(self, __1: GetSchedule.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetSchedule.Response: ...
    def LocatePruningTimestamp(self, __1: LocatePruningTimestamp.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LocatePruningTimestamp.Response: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerPruningAdministrationServiceAsyncStub(SequencerPruningAdministrationServiceStub):
    def Prune(self, __1: SequencerPruning.PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerPruning.PruneResponse]: ...  # type: ignore
    def SetSchedule(self, __1: SetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetSchedule.Response]: ...  # type: ignore
    def SetCron(self, __1: SetCron.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetCron.Response]: ...  # type: ignore
    def SetMaxDuration(self, __1: SetMaxDuration.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetMaxDuration.Response]: ...  # type: ignore
    def SetRetention(self, __1: SetRetention.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetRetention.Response]: ...  # type: ignore
    def ClearSchedule(self, __1: ClearSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ClearSchedule.Response]: ...  # type: ignore
    def GetSchedule(self, __1: GetSchedule.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetSchedule.Response]: ...  # type: ignore
    def LocatePruningTimestamp(self, __1: LocatePruningTimestamp.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LocatePruningTimestamp.Response]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/health/admin/v30/status_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/health/admin/v30/status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/digitalasset/canton/health/admin/v30/status_service.proto\x12(com.digitalasset.canton.health.admin.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\"i\n\x13TopologyQueueStatus\x12\x18\n\x07manager\x18\x01 \x01(\rR\x07manager\x12\x1e\n\ndispatcher\x18\x02 \x01(\rR\ndispatcher\x12\x18\n\x07\x63lients\x18\x03 \x01(\rR\x07\x63lients\"\x0f\n\rStatusRequest\"\x9f\r\n\x0eStatusResponse\x12r\n\x0fnot_initialized\x18\x01 \x01(\x0b\x32G.com.digitalasset.canton.health.admin.v30.StatusResponse.NotInitializedH\x00R\x0enotInitialized\x12[\n\x07success\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.health.admin.v30.StatusResponse.StatusH\x00R\x07success\x1a\xe7\x03\n\x06Status\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12`\n\x05ports\x18\x03 \x03(\x0b\x32J.com.digitalasset.canton.health.admin.v30.StatusResponse.Status.PortsEntryR\x05ports\x12\x14\n\x05\x65xtra\x18\x04 \x01(\x0cR\x05\x65xtra\x12\x16\n\x06\x61\x63tive\x18\x05 \x01(\x08R\x06\x61\x63tive\x12\x66\n\x0ftopology_queues\x18\x06 \x01(\x0b\x32=.com.digitalasset.canton.health.admin.v30.TopologyQueueStatusR\x0etopologyQueues\x12h\n\ncomponents\x18\x07 \x03(\x0b\x32H.com.digitalasset.canton.health.admin.v30.StatusResponse.ComponentStatusR\ncomponents\x1a\x38\n\nPortsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\x1a\xb3\x04\n\x0f\x43omponentStatus\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x65\n\x02ok\x18\x02 \x01(\x0b\x32S.com.digitalasset.canton.health.admin.v30.StatusResponse.ComponentStatus.StatusDataH\x00R\x02ok\x12q\n\x08\x64\x65graded\x18\x03 \x01(\x0b\x32S.com.digitalasset.canton.health.admin.v30.StatusResponse.ComponentStatus.StatusDataH\x00R\x08\x64\x65graded\x12m\n\x06\x66\x61iled\x18\x04 \x01(\x0b\x32S.com.digitalasset.canton.health.admin.v30.StatusResponse.ComponentStatus.StatusDataH\x00R\x06\x66\x61iled\x12k\n\x05\x66\x61tal\x18\x05 \x01(\x0b\x32S.com.digitalasset.canton.health.admin.v30.StatusResponse.ComponentStatus.StatusDataH\x00R\x05\x66\x61tal\x1aL\n\nStatusData\x12>\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scriptionB\x08\n\x06status\x1a\x8f\x03\n\x0eNotInitialized\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\x12\x9c\x01\n\x1awaiting_for_external_input\x18\x02 \x01(\x0e\x32_.com.digitalasset.canton.health.admin.v30.StatusResponse.NotInitialized.WaitingForExternalInputR\x17waitingForExternalInput\"\xc5\x01\n\x17WaitingForExternalInput\x12*\n&WAITING_FOR_EXTERNAL_INPUT_UNSPECIFIED\x10\x00\x12!\n\x1dWAITING_FOR_EXTERNAL_INPUT_ID\x10\x01\x12,\n(WAITING_FOR_EXTERNAL_INPUT_NODE_TOPOLOGY\x10\x02\x12-\n)WAITING_FOR_EXTERNAL_INPUT_INITIALIZATION\x10\x03\x42\n\n\x08response\"P\n\x11HealthDumpRequest\x12;\n\nchunk_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\tchunkSize\"*\n\x12HealthDumpResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xf2\x01\n\x15ParticipantStatusInfo\x12|\n\x11\x63onnected_domains\x18\x01 \x03(\x0b\x32O.com.digitalasset.canton.health.admin.v30.ParticipantStatusInfo.ConnectedDomainR\x10\x63onnectedDomains\x12\x16\n\x06\x61\x63tive\x18\x02 \x01(\x08R\x06\x61\x63tive\x1a\x43\n\x0f\x43onnectedDomain\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x18\n\x07healthy\x18\x02 \x01(\x08R\x07healthy\"\xa5\x02\n\x13SequencerNodeStatus\x12<\n\x1a\x63onnected_participant_uids\x18\x01 \x03(\tR\x18\x63onnectedParticipantUids\x12]\n\tsequencer\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.health.admin.v30.SequencerHealthStatusR\tsequencer\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12T\n\x05\x61\x64min\x18\x04 \x01(\x0b\x32>.com.digitalasset.canton.health.admin.v30.SequencerAdminStatusR\x05\x61\x64min\"g\n\x15SequencerHealthStatus\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\x12\x36\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x64\x65tails\"J\n\x14SequencerAdminStatus\x12\x32\n\x15\x61\x63\x63\x65pts_admin_changes\x18\x01 \x01(\x08R\x13\x61\x63\x63\x65ptsAdminChanges\"1\n\x12MediatorNodeStatus\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\"*\n\x12SetLogLevelRequest\x12\x14\n\x05level\x18\x01 \x01(\tR\x05level\"\x15\n\x13SetLogLevelResponse\"\x16\n\x14GetLastErrorsRequest\"\xb4\x01\n\x15GetLastErrorsResponse\x12]\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x45.com.digitalasset.canton.health.admin.v30.GetLastErrorsResponse.ErrorR\x06\x65rrors\x1a<\n\x05\x45rror\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"5\n\x18GetLastErrorTraceRequest\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\"7\n\x19GetLastErrorTraceResponse\x12\x1a\n\x08messages\x18\x01 \x03(\tR\x08messages2\xd7\x05\n\rStatusService\x12{\n\x06Status\x12\x37.com.digitalasset.canton.health.admin.v30.StatusRequest\x1a\x38.com.digitalasset.canton.health.admin.v30.StatusResponse\x12\x89\x01\n\nHealthDump\x12;.com.digitalasset.canton.health.admin.v30.HealthDumpRequest\x1a<.com.digitalasset.canton.health.admin.v30.HealthDumpResponse0\x01\x12\x8a\x01\n\x0bSetLogLevel\x12<.com.digitalasset.canton.health.admin.v30.SetLogLevelRequest\x1a=.com.digitalasset.canton.health.admin.v30.SetLogLevelResponse\x12\x90\x01\n\rGetLastErrors\x12>.com.digitalasset.canton.health.admin.v30.GetLastErrorsRequest\x1a?.com.digitalasset.canton.health.admin.v30.GetLastErrorsResponse\x12\x9c\x01\n\x11GetLastErrorTrace\x12\x42.com.digitalasset.canton.health.admin.v30.GetLastErrorTraceRequest\x1a\x43.com.digitalasset.canton.health.admin.v30.GetLastErrorTraceResponseBYZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.health.admin.v30.status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v30'
  _globals['_STATUSRESPONSE_STATUS_PORTSENTRY']._loaded_options = None
  _globals['_STATUSRESPONSE_STATUS_PORTSENTRY']._serialized_options = b'8\001'
  _globals['_TOPOLOGYQUEUESTATUS']._serialized_start=171
  _globals['_TOPOLOGYQUEUESTATUS']._serialized_end=276
  _globals['_STATUSREQUEST']._serialized_start=278
  _globals['_STATUSREQUEST']._serialized_end=293
  _globals['_STATUSRESPONSE']._serialized_start=296
  _globals['_STATUSRESPONSE']._serialized_end=1991
  _globals['_STATUSRESPONSE_STATUS']._serialized_start=524
  _globals['_STATUSRESPONSE_STATUS']._serialized_end=1011
  _globals['_STATUSRESPONSE_STATUS_PORTSENTRY']._serialized_start=955
  _globals['_STATUSRESPONSE_STATUS_PORTSENTRY']._serialized_end=1011
  _globals['_STATUSRESPONSE_COMPONENTSTATUS']._serialized_start=1014
  _globals['_STATUSRESPONSE_COMPONENTSTATUS']._serialized_end=1577
  _globals['_STATUSRESPONSE_COMPONENTSTATUS_STATUSDATA']._serialized_start=1491
  _globals['_STATUSRESPONSE_COMPONENTSTATUS_STATUSDATA']._serialized_end=1567
  _globals['_STATUSRESPONSE_NOTINITIALIZED']._serialized_start=1580
  _globals['_STATUSRESPONSE_NOTINITIALIZED']._serialized_end=1979
  _globals['_STATUSRESPONSE_NOTINITIALIZED_WAITINGFOREXTERNALINPUT']._serialized_start=1782
  _globals['_STATUSRESPONSE_NOTINITIALIZED_WAITINGFOREXTERNALINPUT']._serialized_end=1979
  _globals['_HEALTHDUMPREQUEST']._serialized_start=1993
  _globals['_HEALTHDUMPREQUEST']._serialized_end=2073
  _globals['_HEALTHDUMPRESPONSE']._serialized_start=2075
  _globals['_HEALTHDUMPRESPONSE']._serialized_end=2117
  _globals['_PARTICIPANTSTATUSINFO']._serialized_start=2120
  _globals['_PARTICIPANTSTATUSINFO']._serialized_end=2362
  _globals['_PARTICIPANTSTATUSINFO_CONNECTEDDOMAIN']._serialized_start=2295
  _globals['_PARTICIPANTSTATUSINFO_CONNECTEDDOMAIN']._serialized_end=2362
  _globals['_SEQUENCERNODESTATUS']._serialized_start=2365
  _globals['_SEQUENCERNODESTATUS']._serialized_end=2658
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_start=2660
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_end=2763
  _globals['_SEQUENCERADMINSTATUS']._serialized_start=2765
  _globals['_SEQUENCERADMINSTATUS']._serialized_end=2839
  _globals['_MEDIATORNODESTATUS']._serialized_start=2841
  _globals['_MEDIATORNODESTATUS']._serialized_end=2890
  _globals['_SETLOGLEVELREQUEST']._serialized_start=2892
  _globals['_SETLOGLEVELREQUEST']._serialized_end=2934
  _globals['_SETLOGLEVELRESPONSE']._serialized_start=2936
  _globals['_SETLOGLEVELRESPONSE']._serialized_end=2957
  _globals['_GETLASTERRORSREQUEST']._serialized_start=2959
  _globals['_GETLASTERRORSREQUEST']._serialized_end=2981
  _globals['_GETLASTERRORSRESPONSE']._serialized_start=2984
  _globals['_GETLASTERRORSRESPONSE']._serialized_end=3164
  _globals['_GETLASTERRORSRESPONSE_ERROR']._serialized_start=3104
  _globals['_GETLASTERRORSRESPONSE_ERROR']._serialized_end=3164
  _globals['_GETLASTERRORTRACEREQUEST']._serialized_start=3166
  _globals['_GETLASTERRORTRACEREQUEST']._serialized_end=3219
  _globals['_GETLASTERRORTRACERESPONSE']._serialized_start=3221
  _globals['_GETLASTERRORTRACERESPONSE']._serialized_end=3276
  _globals['_STATUSSERVICE']._serialized_start=3279
  _globals['_STATUSSERVICE']._serialized_end=4006
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive_submission_data.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/interactive_submission_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8com/daml/ledger/api/v2/interactive_submission_data.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/value.proto\"\x9e\x01\n\x13PreparedTransaction\x12I\n\x0btransaction\x18\x01 \x01(\x0b\x32\'.com.daml.ledger.api.v2.DamlTransactionR\x0btransaction\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32 .com.daml.ledger.api.v2.MetadataR\x08metadata\"\xef\t\n\x08Metadata\x12U\n\x0esubmitter_info\x18\x01 \x01(\x0b\x32..com.daml.ledger.api.v2.Metadata.SubmitterInfoR\rsubmitterInfo\x12\'\n\x0fsubmission_seed\x18\x02 \x01(\x0cR\x0esubmissionSeed\x12\'\n\x0fsubmission_time\x18\x03 \x01(\x04R\x0esubmissionTime\x12#\n\rused_packages\x18\x04 \x03(\tR\x0cusedPackages\x12H\n\nnode_seeds\x18\x05 \x03(\x0b\x32).com.daml.ledger.api.v2.Metadata.NodeSeedR\tnodeSeeds\x12\x64\n\x12global_key_mapping\x18\x06 \x03(\x0b\x32\x36.com.daml.ledger.api.v2.Metadata.GlobalKeyMappingEntryR\x10globalKeyMapping\x12\x66\n\x10\x64isclosed_events\x18\x07 \x03(\x0b\x32;.com.daml.ledger.api.v2.Metadata.ProcessedDisclosedContractR\x0f\x64isclosedEvents\x12\x37\n\x15ledger_effective_time\x18\x08 \x01(\x04H\x00R\x13ledgerEffectiveTime\x88\x01\x01\x12$\n\x0bworkflow_id\x18\t \x01(\tH\x01R\nworkflowId\x88\x01\x01\x12:\n\x19interpretation_time_nanos\x18\n \x01(\x04R\x17interpretationTimeNanos\x12\x1b\n\tdomain_id\x18\x0b \x01(\tR\x08\x64omainId\x12%\n\x0emediator_group\x18\x0c \x01(\rR\rmediatorGroup\x12%\n\x0etransaction_id\x18\r \x01(\tR\rtransactionId\x1a^\n\rSubmitterInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\x02 \x03(\tR\x06readAs\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x1a\x37\n\x08NodeSeed\x12\x17\n\x07node_id\x18\x01 \x01(\x05R\x06nodeId\x12\x12\n\x04seed\x18\x02 \x01(\x0cR\x04seed\x1a\x90\x01\n\x15GlobalKeyMappingEntry\x12\x33\n\x03key\x18\x01 \x01(\x0b\x32!.com.daml.ledger.api.v2.GlobalKeyR\x03key\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueH\x00R\x05value\x88\x01\x01\x42\x08\n\x06_value\x1a\xa0\x01\n\x1aProcessedDisclosedContract\x12:\n\x08\x63ontract\x18\x01 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.CreateR\x08\x63ontract\x12\x1d\n\ncreated_at\x18\x02 \x01(\x04R\tcreatedAt\x12\'\n\x0f\x64river_metadata\x18\x03 \x01(\x0cR\x0e\x64riverMetadataB\x18\n\x16_ledger_effective_timeB\x0e\n\x0c_workflow_id\"u\n\x0f\x44\x61mlTransaction\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x14\n\x05roots\x18\x02 \x03(\tR\x05roots\x12\x32\n\x05nodes\x18\x03 \x03(\x0b\x32\x1c.com.daml.ledger.api.v2.NodeR\x05nodes\"\x85\x0c\n\x04Node\x12\x1d\n\x07version\x18\x01 \x01(\tH\x01R\x07version\x88\x01\x01\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12\x38\n\x06\x63reate\x18\x03 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.CreateH\x00R\x06\x63reate\x12:\n\x05\x66\x65tch\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.Node.FetchH\x00R\x05\x66\x65tch\x12\x43\n\x08\x65xercise\x18\x05 \x01(\x0b\x32%.com.daml.ledger.api.v2.Node.ExerciseH\x00R\x08\x65xercise\x12\x43\n\x08rollback\x18\x06 \x01(\x0b\x32%.com.daml.ledger.api.v2.Node.RollbackH\x00R\x08rollback\x12N\n\rlookup_by_key\x18\x07 \x01(\x0b\x32(.com.daml.ledger.api.v2.Node.LookupByKeyH\x00R\x0blookupByKey\x1a\xf8\x02\n\x05\x46\x65tch\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12 \n\x0bsignatories\x18\x04 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x05 \x03(\tR\x0cstakeholders\x12%\n\x0e\x61\x63ting_parties\x18\x06 \x03(\tR\ractingParties\x12\x62\n\x14key_with_maintainers\x18\x07 \x01(\x0b\x32\x30.com.daml.ledger.api.v2.GlobalKeyWithMaintainersR\x12keyWithMaintainers\x12\x15\n\x06\x62y_key\x18\x08 \x01(\x08R\x05\x62yKey\x1a\xc6\x03\n\x08\x45xercise\x12\x38\n\x05\x66\x65tch\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.Node.FetchR\x05\x66\x65tch\x12\x45\n\x0cinterface_id\x18\x02 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x1b\n\tchoice_id\x18\x03 \x01(\tR\x08\x63hoiceId\x12@\n\x0c\x63hosen_value\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0b\x63hosenValue\x12\x1c\n\tconsuming\x18\x05 \x01(\x08R\tconsuming\x12\x1a\n\x08\x63hildren\x18\x06 \x03(\tR\x08\x63hildren\x12\x46\n\x0f\x65xercise_result\x18\x07 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x65xerciseResult\x12)\n\x10\x63hoice_observers\x18\x08 \x03(\tR\x0f\x63hoiceObservers\x12-\n\x12\x63hoice_authorizers\x18\t \x03(\tR\x11\x63hoiceAuthorizers\x1a&\n\x08Rollback\x12\x1a\n\x08\x63hildren\x18\x01 \x03(\tR\x08\x63hildren\x1a\xef\x01\n\x0bLookupByKey\x12!\n\x0cpackage_name\x18\x01 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x02 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x42\n\x03key\x18\x03 \x01(\x0b\x32\x30.com.daml.ledger.api.v2.GlobalKeyWithMaintainersR\x03key\x12$\n\x0b\x63ontract_id\x18\x04 \x01(\tH\x00R\ncontractId\x88\x01\x01\x42\x0e\n\x0c_contract_idB\x0b\n\tnode_typeB\n\n\x08_version\"\xc5\x03\n\x06\x43reate\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x39\n\x08\x61rgument\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x08\x61rgument\x12 \n\x0bsignatories\x18\x05 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x06 \x03(\tR\x0cstakeholders\x12,\n\x0fpackage_version\x18\x07 \x01(\tH\x00R\x0epackageVersion\x88\x01\x01\x12o\n\x1bglobal_key_with_maintainers\x18\x08 \x01(\x0b\x32\x30.com.daml.ledger.api.v2.GlobalKeyWithMaintainersR\x18globalKeyWithMaintainersB\x12\n\x10_package_version\"\xb8\x01\n\tGlobalKey\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12/\n\x03key\x18\x03 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x03key\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\"q\n\x18GlobalKeyWithMaintainers\x12\x33\n\x03key\x18\x01 \x01(\x0b\x32!.com.daml.ledger.api.v2.GlobalKeyR\x03key\x12 \n\x0bmaintainers\x18\x02 \x03(\tR\x0bmaintainersB\x9d\x01\n\x16\x63om.daml.ledger.api.v2B#InteractiveSubmissionDataOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive_submission_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B#InteractiveSubmissionDataOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_PREPAREDTRANSACTION']._serialized_start=121
  _globals['_PREPAREDTRANSACTION']._serialized_end=279
  _globals['_METADATA']._serialized_start=282
  _globals['_METADATA']._serialized_end=1545
  _globals['_METADATA_SUBMITTERINFO']._serialized_start=1042
  _globals['_METADATA_SUBMITTERINFO']._serialized_end=1136
  _globals['_METADATA_NODESEED']._serialized_start=1138
  _globals['_METADATA_NODESEED']._serialized_end=1193
  _globals['_METADATA_GLOBALKEYMAPPINGENTRY']._serialized_start=1196
  _globals['_METADATA_GLOBALKEYMAPPINGENTRY']._serialized_end=1340
  _globals['_METADATA_PROCESSEDDISCLOSEDCONTRACT']._serialized_start=1343
  _globals['_METADATA_PROCESSEDDISCLOSEDCONTRACT']._serialized_end=1503
  _globals['_DAMLTRANSACTION']._serialized_start=1547
  _globals['_DAMLTRANSACTION']._serialized_end=1664
  _globals['_NODE']._serialized_start=1667
  _globals['_NODE']._serialized_end=3208
  _globals['_NODE_FETCH']._serialized_start=2068
  _globals['_NODE_FETCH']._serialized_end=2444
  _globals['_NODE_EXERCISE']._serialized_start=2447
  _globals['_NODE_EXERCISE']._serialized_end=2901
  _globals['_NODE_ROLLBACK']._serialized_start=2903
  _globals['_NODE_ROLLBACK']._serialized_end=2941
  _globals['_NODE_LOOKUPBYKEY']._serialized_start=2944
  _globals['_NODE_LOOKUPBYKEY']._serialized_end=3183
  _globals['_CREATE']._serialized_start=3211
  _globals['_CREATE']._serialized_end=3664
  _globals['_GLOBALKEY']._serialized_start=3667
  _globals['_GLOBALKEY']._serialized_end=3851
  _globals['_GLOBALKEYWITHMAINTAINERS']._serialized_start=3853
  _globals['_GLOBALKEYWITHMAINTAINERS']._serialized_end=3966
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...api.v0 import sequencer_connection_pb2 as _sequencer_connection_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetConnectionRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetConnectionResponse(_message.Message):
    __slots__ = ("sequencer_connections", "sequencerTrustThreshold")
    SEQUENCER_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCERTRUSTTHRESHOLD_FIELD_NUMBER: _ClassVar[int]
    sequencer_connections: _containers.RepeatedCompositeFieldContainer[_sequencer_connection_pb2.SequencerConnection]
    sequencerTrustThreshold: int
    def __init__(self, sequencer_connections: _Optional[_Iterable[_Union[_sequencer_connection_pb2.SequencerConnection, _Mapping]]] = ..., sequencerTrustThreshold: _Optional[int] = ...) -> None: ...

class SetConnectionRequest(_message.Message):
    __slots__ = ("sequencer_connections", "sequencerTrustThreshold")
    SEQUENCER_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCERTRUSTTHRESHOLD_FIELD_NUMBER: _ClassVar[int]
    sequencer_connections: _containers.RepeatedCompositeFieldContainer[_sequencer_connection_pb2.SequencerConnection]
    sequencerTrustThreshold: int
    def __init__(self, sequencer_connections: _Optional[_Iterable[_Union[_sequencer_connection_pb2.SequencerConnection, _Mapping]]] = ..., sequencerTrustThreshold: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .crypto_pb2 import CryptoKeyFormat, CryptoKeyPair, EncryptionKeyPair, EncryptionKeyScheme, EncryptionPrivateKey, EncryptionPublicKey, HashAlgorithm, Hmac, HmacAlgorithm, KeyPurpose, PrivateKey, PublicKey, PublicKeyWithName, Salt, Signature, SignatureFormat, SigningKeyPair, SigningKeyScheme, SigningPrivateKey, SigningPublicKey, SymmetricKey, SymmetricKeyScheme

__all__ = [
    "CryptoKeyFormat",
    "CryptoKeyPair",
    "EncryptionKeyPair",
    "EncryptionKeyScheme",
    "EncryptionPrivateKey",
    "EncryptionPublicKey",
    "HashAlgorithm",
    "Hmac",
    "HmacAlgorithm",
    "KeyPurpose",
    "PrivateKey",
    "PublicKey",
    "PublicKeyWithName",
    "Salt",
    "Signature",
    "SignatureFormat",
    "SigningKeyPair",
    "SigningKeyScheme",
    "SigningPrivateKey",
    "SigningPublicKey",
    "SymmetricKey",
    "SymmetricKeyScheme",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v0/service_agreement.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v0/service_agreement.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/digitalasset/canton/domain/api/v0/service_agreement.proto\x12%com.digitalasset.canton.domain.api.v0\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\"\x1c\n\x1aGetServiceAgreementRequest\"r\n\x1bGetServiceAgreementResponse\x12S\n\tagreement\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.ServiceAgreementR\tagreementBVZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v0.service_agreement_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0'
  _globals['_GETSERVICEAGREEMENTREQUEST']._serialized_start=158
  _globals['_GETSERVICEAGREEMENTREQUEST']._serialized_end=186
  _globals['_GETSERVICEAGREEMENTRESPONSE']._serialized_start=188
  _globals['_GETSERVICEAGREEMENTRESPONSE']._serialized_end=302
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/state_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/state_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_event__pb2
from . import reassignment_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*com/daml/ledger/api/v2/state_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/event.proto\x1a)com/daml/ledger/api/v2/reassignment.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\"\xa2\x01\n\x19GetActiveContractsRequest\x12\x41\n\x06\x66ilter\x18\x01 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFilterR\x06\x66ilter\x12\x18\n\x07verbose\x18\x02 \x01(\x08R\x07verbose\x12(\n\x10\x61\x63tive_at_offset\x18\x03 \x01(\x03R\x0e\x61\x63tiveAtOffset\"\xe6\x02\n\x1aGetActiveContractsResponse\x12\x1f\n\x0bworkflow_id\x18\x02 \x01(\tR\nworkflowId\x12Q\n\x0f\x61\x63tive_contract\x18\x03 \x01(\x0b\x32&.com.daml.ledger.api.v2.ActiveContractH\x00R\x0e\x61\x63tiveContract\x12\x63\n\x15incomplete_unassigned\x18\x04 \x01(\x0b\x32,.com.daml.ledger.api.v2.IncompleteUnassignedH\x00R\x14incompleteUnassigned\x12]\n\x13incomplete_assigned\x18\x05 \x01(\x0b\x32*.com.daml.ledger.api.v2.IncompleteAssignedH\x00R\x12incompleteAssignedB\x10\n\x0e\x63ontract_entry\"\xab\x01\n\x0e\x41\x63tiveContract\x12I\n\rcreated_event\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.CreatedEventR\x0c\x63reatedEvent\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12\x31\n\x14reassignment_counter\x18\x03 \x01(\x04R\x13reassignmentCounter\"\xb5\x01\n\x14IncompleteUnassigned\x12I\n\rcreated_event\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.CreatedEventR\x0c\x63reatedEvent\x12R\n\x10unassigned_event\x18\x02 \x01(\x0b\x32\'.com.daml.ledger.api.v2.UnassignedEventR\x0funassignedEvent\"b\n\x12IncompleteAssigned\x12L\n\x0e\x61ssigned_event\x18\x01 \x01(\x0b\x32%.com.daml.ledger.api.v2.AssignedEventR\rassignedEvent\"Y\n\x1aGetConnectedDomainsRequest\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\"\xb2\x02\n\x1bGetConnectedDomainsResponse\x12p\n\x11\x63onnected_domains\x18\x01 \x03(\x0b\x32\x43.com.daml.ledger.api.v2.GetConnectedDomainsResponse.ConnectedDomainR\x10\x63onnectedDomains\x1a\xa0\x01\n\x0f\x43onnectedDomain\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12M\n\npermission\x18\x03 \x01(\x0e\x32-.com.daml.ledger.api.v2.ParticipantPermissionR\npermission\"\x15\n\x13GetLedgerEndRequest\".\n\x14GetLedgerEndResponse\x12\x16\n\x06offset\x18\x01 \x01(\x03R\x06offset\"\x1f\n\x1dGetLatestPrunedOffsetsRequest\"\xcc\x01\n\x1eGetLatestPrunedOffsetsResponse\x12J\n\"participant_pruned_up_to_inclusive\x18\x01 \x01(\x03R\x1eparticipantPrunedUpToInclusive\x12^\n-all_divulged_contracts_pruned_up_to_inclusive\x18\x02 \x01(\x03R\'allDivulgedContractsPrunedUpToInclusive*\xb7\x01\n\x15ParticipantPermission\x12&\n\"PARTICIPANT_PERMISSION_UNSPECIFIED\x10\x00\x12%\n!PARTICIPANT_PERMISSION_SUBMISSION\x10\x01\x12\'\n#PARTICIPANT_PERMISSION_CONFIRMATION\x10\x02\x12&\n\"PARTICIPANT_PERMISSION_OBSERVATION\x10\x03\x32\x82\x04\n\x0cStateService\x12}\n\x12GetActiveContracts\x12\x31.com.daml.ledger.api.v2.GetActiveContractsRequest\x1a\x32.com.daml.ledger.api.v2.GetActiveContractsResponse0\x01\x12~\n\x13GetConnectedDomains\x12\x32.com.daml.ledger.api.v2.GetConnectedDomainsRequest\x1a\x33.com.daml.ledger.api.v2.GetConnectedDomainsResponse\x12i\n\x0cGetLedgerEnd\x12+.com.daml.ledger.api.v2.GetLedgerEndRequest\x1a,.com.daml.ledger.api.v2.GetLedgerEndResponse\x12\x87\x01\n\x16GetLatestPrunedOffsets\x12\x35.com.daml.ledger.api.v2.GetLatestPrunedOffsetsRequest\x1a\x36.com.daml.ledger.api.v2.GetLatestPrunedOffsetsResponseB\x90\x01\n\x16\x63om.daml.ledger.api.v2B\x16StateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.state_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\026StateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_PARTICIPANTPERMISSION']._serialized_start=1894
  _globals['_PARTICIPANTPERMISSION']._serialized_end=2077
  _globals['_GETACTIVECONTRACTSREQUEST']._serialized_start=199
  _globals['_GETACTIVECONTRACTSREQUEST']._serialized_end=361
  _globals['_GETACTIVECONTRACTSRESPONSE']._serialized_start=364
  _globals['_GETACTIVECONTRACTSRESPONSE']._serialized_end=722
  _globals['_ACTIVECONTRACT']._serialized_start=725
  _globals['_ACTIVECONTRACT']._serialized_end=896
  _globals['_INCOMPLETEUNASSIGNED']._serialized_start=899
  _globals['_INCOMPLETEUNASSIGNED']._serialized_end=1080
  _globals['_INCOMPLETEASSIGNED']._serialized_start=1082
  _globals['_INCOMPLETEASSIGNED']._serialized_end=1180
  _globals['_GETCONNECTEDDOMAINSREQUEST']._serialized_start=1182
  _globals['_GETCONNECTEDDOMAINSREQUEST']._serialized_end=1271
  _globals['_GETCONNECTEDDOMAINSRESPONSE']._serialized_start=1274
  _globals['_GETCONNECTEDDOMAINSRESPONSE']._serialized_end=1580
  _globals['_GETCONNECTEDDOMAINSRESPONSE_CONNECTEDDOMAIN']._serialized_start=1420
  _globals['_GETCONNECTEDDOMAINSRESPONSE_CONNECTEDDOMAIN']._serialized_end=1580
  _globals['_GETLEDGERENDREQUEST']._serialized_start=1582
  _globals['_GETLEDGERENDREQUEST']._serialized_end=1603
  _globals['_GETLEDGERENDRESPONSE']._serialized_start=1605
  _globals['_GETLEDGERENDRESPONSE']._serialized_end=1651
  _globals['_GETLATESTPRUNEDOFFSETSREQUEST']._serialized_start=1653
  _globals['_GETLATESTPRUNEDOFFSETSREQUEST']._serialized_end=1684
  _globals['_GETLATESTPRUNEDOFFSETSRESPONSE']._serialized_start=1687
  _globals['_GETLATESTPRUNEDOFFSETSRESPONSE']._serialized_end=1891
  _globals['_STATESERVICE']._serialized_start=2080
  _globals['_STATESERVICE']._serialized_end=2594
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/participant_transaction.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v0/participant_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_common__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_merkle__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAcom/digitalasset/canton/protocol/v0/participant_transaction.proto\x12#com.digitalasset.canton.protocol.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x30\x63om/digitalasset/canton/protocol/v0/common.proto\x1a\x30\x63om/digitalasset/canton/protocol/v0/merkle.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x91\x03\n\x14\x45ncryptedViewMessage\x12\x1b\n\tview_tree\x18\x01 \x01(\x0cR\x08viewTree\x12t\n\x1fsubmitter_participant_signature\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\x1dsubmitterParticipantSignature\x12\x1b\n\tview_hash\x18\x03 \x01(\x0cR\x08viewHash\x12`\n\nrandomness\x18\x04 \x03(\x0b\x32@.com.digitalasset.canton.protocol.v0.ParticipantRandomnessLookupR\nrandomness\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainId\x12J\n\tview_type\x18\x06 \x01(\x0e\x32-.com.digitalasset.canton.protocol.v0.ViewTypeR\x08viewType\"g\n\x18LightTransactionViewTree\x12K\n\x04tree\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v0.GenTransactionTreeR\x04tree\"\xe4\x02\n\x11SubmitterMetadata\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12\x15\n\x06\x61\x63t_as\x18\x02 \x03(\tR\x05\x61\x63tAs\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x04 \x01(\tR\tcommandId\x12\x33\n\x15submitter_participant\x18\x05 \x01(\tR\x14submitterParticipant\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12[\n\x0c\x64\x65\x64up_period\x18\x07 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.DeduplicationPeriodR\x0b\x64\x65\x64upPeriod\"r\n\x13\x44\x65\x64uplicationPeriod\x12\x37\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x08\x64uration\x12\x18\n\x06offset\x18\x02 \x01(\x0cH\x00R\x06offsetB\x08\n\x06period\"\xd0\x01\n\x0e\x43ommonMetadata\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12/\n\x13\x63onfirmation_policy\x18\x02 \x01(\x0cR\x12\x63onfirmationPolicy\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\x1f\n\x0bmediator_id\x18\x05 \x01(\tR\nmediatorId\"\xf5\x01\n\x13ParticipantMetadata\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12;\n\x0bledger_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nledgerTime\x12\x43\n\x0fsubmission_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0esubmissionTime\x12\x1f\n\x0bworkflow_id\x18\x04 \x01(\tR\nworkflowId\"\xa0\x02\n\x08ViewNode\x12\\\n\x10view_common_data\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x0eviewCommonData\x12\x66\n\x15view_participant_data\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x13viewParticipantData\x12N\n\x08subviews\x18\x03 \x03(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x08subviews\"\xb8\x01\n\x0eViewCommonData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12K\n\tinformees\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.protocol.v0.InformeeR\tinformees\x12\x1c\n\tthreshold\x18\x03 \x01(\x05R\tthreshold\"8\n\x08Informee\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x16\n\x06weight\x18\x02 \x01(\x05R\x06weight\"\xd8\n\n\x13ViewParticipantData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12g\n\x0b\x63ore_inputs\x18\x02 \x03(\x0b\x32\x46.com.digitalasset.canton.protocol.v0.ViewParticipantData.InputContractR\ncoreInputs\x12k\n\x0c\x63reated_core\x18\x03 \x03(\x0b\x32H.com.digitalasset.canton.protocol.v0.ViewParticipantData.CreatedContractR\x0b\x63reatedCore\x12K\n#created_in_subview_archived_in_core\x18\x04 \x03(\tR\x1e\x63reatedInSubviewArchivedInCore\x12i\n\rresolved_keys\x18\x05 \x03(\x0b\x32\x44.com.digitalasset.canton.protocol.v0.ViewParticipantData.ResolvedKeyR\x0cresolvedKeys\x12\x65\n\x12\x61\x63tion_description\x18\x06 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.ActionDescriptionR\x11\x61\x63tionDescription\x12s\n\x10rollback_context\x18\x07 \x01(\x0b\x32H.com.digitalasset.canton.protocol.v0.ViewParticipantData.RollbackContextR\x0frollbackContext\x1a\xb3\x01\n\x0f\x43reatedContract\x12U\n\x08\x63ontract\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.SerializableContractR\x08\x63ontract\x12(\n\x10\x63onsumed_in_core\x18\x02 \x01(\x08R\x0e\x63onsumedInCore\x12\x1f\n\x0brolled_back\x18\x03 \x01(\x08R\nrolledBack\x1a\x82\x01\n\rInputContract\x12U\n\x08\x63ontract\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v0.SerializableContractR\x08\x63ontract\x12\x1a\n\x08\x63onsumed\x18\x02 \x01(\x08R\x08\x63onsumed\x1a\xd8\x01\n\x0bResolvedKey\x12@\n\x03key\x18\x01 \x01(\x0b\x32..com.digitalasset.canton.protocol.v0.GlobalKeyR\x03key\x12!\n\x0b\x63ontract_id\x18\x02 \x01(\tH\x00R\ncontractId\x12V\n\x04\x66ree\x18\x03 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v0.ViewParticipantData.FreeKeyH\x00R\x04\x66reeB\x0c\n\nresolution\x1a+\n\x07\x46reeKey\x12 \n\x0bmaintainers\x18\x01 \x03(\tR\x0bmaintainers\x1aW\n\x0fRollbackContext\x12%\n\x0erollback_scope\x18\x01 \x03(\x05R\rrollbackScope\x12\x1d\n\nnext_child\x18\x02 \x01(\x05R\tnextChild\"\xc6\x08\n\x11\x41\x63tionDescription\x12h\n\x06\x63reate\x18\x01 \x01(\x0b\x32N.com.digitalasset.canton.protocol.v0.ActionDescription.CreateActionDescriptionH\x00R\x06\x63reate\x12n\n\x08\x65xercise\x18\x02 \x01(\x0b\x32P.com.digitalasset.canton.protocol.v0.ActionDescription.ExerciseActionDescriptionH\x00R\x08\x65xercise\x12\x65\n\x05\x66\x65tch\x18\x03 \x01(\x0b\x32M.com.digitalasset.canton.protocol.v0.ActionDescription.FetchActionDescriptionH\x00R\x05\x66\x65tch\x12y\n\rlookup_by_key\x18\x04 \x01(\x0b\x32S.com.digitalasset.canton.protocol.v0.ActionDescription.LookupByKeyActionDescriptionH\x00R\x0blookupByKey\x1aq\n\x17\x43reateActionDescription\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x1b\n\tnode_seed\x18\x02 \x01(\x0cR\x08nodeSeed\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x1a\x80\x02\n\x19\x45xerciseActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x63hoice\x18\x02 \x01(\tR\x06\x63hoice\x12!\n\x0c\x63hosen_value\x18\x03 \x01(\x0cR\x0b\x63hosenValue\x12\x16\n\x06\x61\x63tors\x18\x04 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x05 \x01(\x08R\x05\x62yKey\x12\x1b\n\tnode_seed\x18\x06 \x01(\x0cR\x08nodeSeed\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\x12\x16\n\x06\x66\x61iled\x18\x08 \x01(\x08R\x06\x66\x61iled\x1a\x8d\x01\n\x16\x46\x65tchActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x61\x63tors\x18\x02 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x03 \x01(\x08R\x05\x62yKey\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\x1a`\n\x1cLookupByKeyActionDescription\x12@\n\x03key\x18\x01 \x01(\x0b\x32..com.digitalasset.canton.protocol.v0.GlobalKeyR\x03keyB\r\n\x0b\x64\x65scription\"_\n\x1bParticipantRandomnessLookup\x12 \n\x0bparticipant\x18\x01 \x01(\tR\x0bparticipant\x12\x1e\n\nrandomness\x18\x02 \x01(\x0cR\nrandomness\"v\n\x0fInformeeMessage\x12\x63\n\x12\x66ull_informee_tree\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.FullInformeeTreeR\x10\x66ullInformeeTree\"_\n\x10\x46ullInformeeTree\x12K\n\x04tree\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v0.GenTransactionTreeR\x04tree\"\xb1\x01\n\x0fRootHashMessage\x12\x1b\n\troot_hash\x18\x01 \x01(\x0cR\x08rootHash\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12J\n\tview_type\x18\x03 \x01(\x0e\x32-.com.digitalasset.canton.protocol.v0.ViewTypeR\x08viewType\x12\x18\n\x07payload\x18\x04 \x01(\x0cR\x07payloadBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.participant_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_start=320
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_end=721
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_start=723
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_end=826
  _globals['_SUBMITTERMETADATA']._serialized_start=829
  _globals['_SUBMITTERMETADATA']._serialized_end=1185
  _globals['_DEDUPLICATIONPERIOD']._serialized_start=1187
  _globals['_DEDUPLICATIONPERIOD']._serialized_end=1301
  _globals['_COMMONMETADATA']._serialized_start=1304
  _globals['_COMMONMETADATA']._serialized_end=1512
  _globals['_PARTICIPANTMETADATA']._serialized_start=1515
  _globals['_PARTICIPANTMETADATA']._serialized_end=1760
  _globals['_VIEWNODE']._serialized_start=1763
  _globals['_VIEWNODE']._serialized_end=2051
  _globals['_VIEWCOMMONDATA']._serialized_start=2054
  _globals['_VIEWCOMMONDATA']._serialized_end=2238
  _globals['_INFORMEE']._serialized_start=2240
  _globals['_INFORMEE']._serialized_end=2296
  _globals['_VIEWPARTICIPANTDATA']._serialized_start=2299
  _globals['_VIEWPARTICIPANTDATA']._serialized_end=3667
  _globals['_VIEWPARTICIPANTDATA_CREATEDCONTRACT']._serialized_start=3002
  _globals['_VIEWPARTICIPANTDATA_CREATEDCONTRACT']._serialized_end=3181
  _globals['_VIEWPARTICIPANTDATA_INPUTCONTRACT']._serialized_start=3184
  _globals['_VIEWPARTICIPANTDATA_INPUTCONTRACT']._serialized_end=3314
  _globals['_VIEWPARTICIPANTDATA_RESOLVEDKEY']._serialized_start=3317
  _globals['_VIEWPARTICIPANTDATA_RESOLVEDKEY']._serialized_end=3533
  _globals['_VIEWPARTICIPANTDATA_FREEKEY']._serialized_start=3535
  _globals['_VIEWPARTICIPANTDATA_FREEKEY']._serialized_end=3578
  _globals['_VIEWPARTICIPANTDATA_ROLLBACKCONTEXT']._serialized_start=3580
  _globals['_VIEWPARTICIPANTDATA_ROLLBACKCONTEXT']._serialized_end=3667
  _globals['_ACTIONDESCRIPTION']._serialized_start=3670
  _globals['_ACTIONDESCRIPTION']._serialized_end=4764
  _globals['_ACTIONDESCRIPTION_CREATEACTIONDESCRIPTION']._serialized_start=4135
  _globals['_ACTIONDESCRIPTION_CREATEACTIONDESCRIPTION']._serialized_end=4248
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_start=4251
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_end=4507
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_start=4510
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_end=4651
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_start=4653
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_end=4749
  _globals['_PARTICIPANTRANDOMNESSLOOKUP']._serialized_start=4766
  _globals['_PARTICIPANTRANDOMNESSLOOKUP']._serialized_end=4861
  _globals['_INFORMEEMESSAGE']._serialized_start=4863
  _globals['_INFORMEEMESSAGE']._serialized_end=4981
  _globals['_FULLINFORMEETREE']._serialized_start=4983
  _globals['_FULLINFORMEETREE']._serialized_end=5078
  _globals['_ROOTHASHMESSAGE']._serialized_start=5081
  _globals['_ROOTHASHMESSAGE']._serialized_end=5258
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/admin/command_inspection_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/admin/command_inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2
from .. import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_commands__pb2
from .. import completion_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_completion__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/daml/ledger/api/v1/admin/command_inspection_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a\"com/daml/ledger/api/v1/value.proto\x1a%com/daml/ledger/api/v1/commands.proto\x1a\'com/daml/ledger/api/v1/completion.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x17GetCommandStatusRequest\x12*\n\x11\x63ommand_id_prefix\x18\x01 \x01(\tR\x0f\x63ommandIdPrefix\x12@\n\x05state\x18\x02 \x01(\x0e\x32*.com.daml.ledger.api.v1.admin.CommandStateR\x05state\x12\x14\n\x05limit\x18\x03 \x01(\rR\x05limit\"\xd4\n\n\x18GetCommandStatusResponse\x12k\n\x0e\x63ommand_status\x18\x01 \x03(\x0b\x32\x44.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatusR\rcommandStatus\x1a\xca\t\n\rCommandStatus\x12\x34\n\x07started\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07started\x12\x38\n\tcompleted\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcompleted\x12\x42\n\ncompletion\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v1.CompletionR\ncompletion\x12@\n\x05state\x18\x04 \x01(\x0e\x32*.com.daml.ledger.api.v1.admin.CommandStateR\x05state\x12;\n\x08\x63ommands\x18\x05 \x03(\x0b\x32\x1f.com.daml.ledger.api.v1.CommandR\x08\x63ommands\x12\x85\x01\n\x12request_statistics\x18\x06 \x01(\x0b\x32V.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.RequestStatisticsR\x11requestStatistics\x12m\n\x07updates\x18\x07 \x01(\x0b\x32S.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.CommandUpdatesR\x07updates\x1at\n\x11RequestStatistics\x12\x1c\n\tenvelopes\x18\x01 \x01(\rR\tenvelopes\x12!\n\x0crequest_size\x18\x02 \x01(\rR\x0brequestSize\x12\x1e\n\nrecipients\x18\x03 \x01(\rR\nrecipients\x1a\x98\x04\n\x0e\x43ommandUpdates\x12v\n\x07\x63reated\x18\x01 \x03(\x0b\x32\\.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.CommandUpdates.ContractR\x07\x63reated\x12x\n\x08\x61rchived\x18\x02 \x03(\x0b\x32\\.com.daml.ledger.api.v1.admin.GetCommandStatusResponse.CommandStatus.CommandUpdates.ContractR\x08\x61rchived\x12\x1c\n\texercised\x18\x03 \x01(\rR\texercised\x12\x18\n\x07\x66\x65tched\x18\x04 \x01(\rR\x07\x66\x65tched\x12\'\n\x10looked_up_by_key\x18\x05 \x01(\rR\rlookedUpByKey\x1a\xb2\x01\n\x08\x43ontract\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12@\n\x0c\x63ontract_key\x18\x03 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueR\x0b\x63ontractKey*_\n\x0c\x43ommandState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_PENDING\x10\x01\x12\x13\n\x0fSTATE_SUCCEEDED\x10\x02\x12\x10\n\x0cSTATE_FAILED\x10\x03\x32\x9e\x01\n\x18\x43ommandInspectionService\x12\x81\x01\n\x10GetCommandStatus\x12\x35.com.daml.ledger.api.v1.admin.GetCommandStatusRequest\x1a\x36.com.daml.ledger.api.v1.admin.GetCommandStatusResponseB\xae\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\"CommandInspectionServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.admin.command_inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v1.adminB\"CommandInspectionServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin'
  _globals['_COMMANDSTATE']._serialized_start=1771
  _globals['_COMMANDSTATE']._serialized_end=1866
  _globals['_GETCOMMANDSTATUSREQUEST']._serialized_start=245
  _globals['_GETCOMMANDSTATUSREQUEST']._serialized_end=402
  _globals['_GETCOMMANDSTATUSRESPONSE']._serialized_start=405
  _globals['_GETCOMMANDSTATUSRESPONSE']._serialized_end=1769
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS']._serialized_start=543
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS']._serialized_end=1769
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_REQUESTSTATISTICS']._serialized_start=1114
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_REQUESTSTATISTICS']._serialized_end=1230
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES']._serialized_start=1233
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES']._serialized_end=1769
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES_CONTRACT']._serialized_start=1591
  _globals['_GETCOMMANDSTATUSRESPONSE_COMMANDSTATUS_COMMANDUPDATES_CONTRACT']._serialized_end=1769
  _globals['_COMMANDINSPECTIONSERVICE']._serialized_start=1869
  _globals['_COMMANDINSPECTIONSERVICE']._serialized_end=2027
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v0 import crypto_pb2 as _crypto_pb2
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v0 import topology_pb2 as _topology_pb2
from ....protocol.v1 import sequencing_pb2 as _sequencing_pb2_1
from ....protocol.v2 import domain_params_pb2 as _domain_params_pb2
from ....protocol.v0 import topology_ext_pb2 as _topology_ext_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListNamespaceDelegationRequest(_message.Message):
    __slots__ = ("base_query", "filter_namespace")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_namespace: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_namespace: _Optional[str] = ...) -> None: ...

class ListNamespaceDelegationResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item", "target_key_fingerprint")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        TARGET_KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.NamespaceDelegation
        target_key_fingerprint: str
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.NamespaceDelegation, _Mapping]] = ..., target_key_fingerprint: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListNamespaceDelegationResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListNamespaceDelegationResult.Result, _Mapping]]] = ...) -> None: ...

class ListIdentifierDelegationRequest(_message.Message):
    __slots__ = ("base_query", "filter_uid")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_UID_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_uid: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_uid: _Optional[str] = ...) -> None: ...

class ListIdentifierDelegationResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item", "target_key_fingerprint")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        TARGET_KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.IdentifierDelegation
        target_key_fingerprint: str
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.IdentifierDelegation, _Mapping]] = ..., target_key_fingerprint: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListIdentifierDelegationResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListIdentifierDelegationResult.Result, _Mapping]]] = ...) -> None: ...

class BaseQuery(_message.Message):
    __slots__ = ("filter_store", "use_state_store", "operation", "filter_operation", "snapshot", "head_state", "range", "filter_signed_key", "protocol_version")
    class TimeRange(_message.Message):
        __slots__ = ("until",)
        FROM_FIELD_NUMBER: _ClassVar[int]
        UNTIL_FIELD_NUMBER: _ClassVar[int]
        until: _timestamp_pb2.Timestamp
        def __init__(self, until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., **kwargs) -> None: ...
    FILTER_STORE_FIELD_NUMBER: _ClassVar[int]
    USE_STATE_STORE_FIELD_NUMBER: _ClassVar[int]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    FILTER_OPERATION_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    HEAD_STATE_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    FILTER_SIGNED_KEY_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    filter_store: str
    use_state_store: bool
    operation: _topology_pb2.TopologyChangeOp
    filter_operation: bool
    snapshot: _timestamp_pb2.Timestamp
    head_state: _empty_pb2.Empty
    range: BaseQuery.TimeRange
    filter_signed_key: str
    protocol_version: _wrappers_pb2.StringValue
    def __init__(self, filter_store: _Optional[str] = ..., use_state_store: bool = ..., operation: _Optional[_Union[_topology_pb2.TopologyChangeOp, str]] = ..., filter_operation: bool = ..., snapshot: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., head_state: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., range: _Optional[_Union[BaseQuery.TimeRange, _Mapping]] = ..., filter_signed_key: _Optional[str] = ..., protocol_version: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class BaseResult(_message.Message):
    __slots__ = ("store", "sequenced", "valid_from", "valid_until", "operation", "serialized", "signed_by_fingerprint")
    STORE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCED_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SERIALIZED_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    store: str
    sequenced: _timestamp_pb2.Timestamp
    valid_from: _timestamp_pb2.Timestamp
    valid_until: _timestamp_pb2.Timestamp
    operation: _topology_pb2.TopologyChangeOp
    serialized: bytes
    signed_by_fingerprint: str
    def __init__(self, store: _Optional[str] = ..., sequenced: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., valid_from: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., valid_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., operation: _Optional[_Union[_topology_pb2.TopologyChangeOp, str]] = ..., serialized: _Optional[bytes] = ..., signed_by_fingerprint: _Optional[str] = ...) -> None: ...

class ListPartyToParticipantResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.PartyToParticipant
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.PartyToParticipant, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListPartyToParticipantResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListPartyToParticipantResult.Result, _Mapping]]] = ...) -> None: ...

class ListPartyToParticipantRequest(_message.Message):
    __slots__ = ("base_query", "filter_party", "filter_participant", "filter_request_side", "filter_permission")
    class FilterRequestSide(_message.Message):
        __slots__ = ("value",)
        VALUE_FIELD_NUMBER: _ClassVar[int]
        value: _topology_pb2.RequestSide
        def __init__(self, value: _Optional[_Union[_topology_pb2.RequestSide, str]] = ...) -> None: ...
    class FilterPermission(_message.Message):
        __slots__ = ("value",)
        VALUE_FIELD_NUMBER: _ClassVar[int]
        value: _topology_pb2.ParticipantPermission
        def __init__(self, value: _Optional[_Union[_topology_pb2.ParticipantPermission, str]] = ...) -> None: ...
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    FILTER_REQUEST_SIDE_FIELD_NUMBER: _ClassVar[int]
    FILTER_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_party: str
    filter_participant: str
    filter_request_side: ListPartyToParticipantRequest.FilterRequestSide
    filter_permission: ListPartyToParticipantRequest.FilterPermission
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_party: _Optional[str] = ..., filter_participant: _Optional[str] = ..., filter_request_side: _Optional[_Union[ListPartyToParticipantRequest.FilterRequestSide, _Mapping]] = ..., filter_permission: _Optional[_Union[ListPartyToParticipantRequest.FilterPermission, _Mapping]] = ...) -> None: ...

class ListOwnerToKeyMappingRequest(_message.Message):
    __slots__ = ("base_query", "filter_key_owner_type", "filter_key_owner_uid", "filter_key_purpose")
    class FilterKeyPurpose(_message.Message):
        __slots__ = ("value",)
        VALUE_FIELD_NUMBER: _ClassVar[int]
        value: _crypto_pb2.KeyPurpose
        def __init__(self, value: _Optional[_Union[_crypto_pb2.KeyPurpose, str]] = ...) -> None: ...
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_KEY_OWNER_TYPE_FIELD_NUMBER: _ClassVar[int]
    FILTER_KEY_OWNER_UID_FIELD_NUMBER: _ClassVar[int]
    FILTER_KEY_PURPOSE_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_key_owner_type: str
    filter_key_owner_uid: str
    filter_key_purpose: ListOwnerToKeyMappingRequest.FilterKeyPurpose
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_key_owner_type: _Optional[str] = ..., filter_key_owner_uid: _Optional[str] = ..., filter_key_purpose: _Optional[_Union[ListOwnerToKeyMappingRequest.FilterKeyPurpose, _Mapping]] = ...) -> None: ...

class ListOwnerToKeyMappingResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item", "key_fingerprint")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.OwnerToKeyMapping
        key_fingerprint: str
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.OwnerToKeyMapping, _Mapping]] = ..., key_fingerprint: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListOwnerToKeyMappingResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListOwnerToKeyMappingResult.Result, _Mapping]]] = ...) -> None: ...

class ListSignedLegalIdentityClaimRequest(_message.Message):
    __slots__ = ("base_query", "filter_uid")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_UID_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_uid: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_uid: _Optional[str] = ...) -> None: ...

class ListSignedLegalIdentityClaimResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.SignedLegalIdentityClaim
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.SignedLegalIdentityClaim, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListSignedLegalIdentityClaimResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListSignedLegalIdentityClaimResult.Result, _Mapping]]] = ...) -> None: ...

class ListVettedPackagesRequest(_message.Message):
    __slots__ = ("base_query", "filter_participant")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_participant: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_participant: _Optional[str] = ...) -> None: ...

class ListVettedPackagesResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.VettedPackages
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.VettedPackages, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListVettedPackagesResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListVettedPackagesResult.Result, _Mapping]]] = ...) -> None: ...

class ListDomainParametersChangesRequest(_message.Message):
    __slots__ = ("base_query",)
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ...) -> None: ...

class ListDomainParametersChangesResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "v0", "v1", "v2")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        V0_FIELD_NUMBER: _ClassVar[int]
        V1_FIELD_NUMBER: _ClassVar[int]
        V2_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        v0: _sequencing_pb2.DynamicDomainParameters
        v1: _sequencing_pb2_1.DynamicDomainParameters
        v2: _domain_params_pb2.DynamicDomainParameters
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., v0: _Optional[_Union[_sequencing_pb2.DynamicDomainParameters, _Mapping]] = ..., v1: _Optional[_Union[_sequencing_pb2_1.DynamicDomainParameters, _Mapping]] = ..., v2: _Optional[_Union[_domain_params_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListDomainParametersChangesResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListDomainParametersChangesResult.Result, _Mapping]]] = ...) -> None: ...

class ListAvailableStoresRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListAvailableStoresResult(_message.Message):
    __slots__ = ("store_ids",)
    STORE_IDS_FIELD_NUMBER: _ClassVar[int]
    store_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, store_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ListParticipantDomainStateRequest(_message.Message):
    __slots__ = ("base_query", "filter_domain", "filter_participant")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    FILTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_domain: str
    filter_participant: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_domain: _Optional[str] = ..., filter_participant: _Optional[str] = ...) -> None: ...

class ListParticipantDomainStateResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.ParticipantState
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.ParticipantState, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListParticipantDomainStateResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListParticipantDomainStateResult.Result, _Mapping]]] = ...) -> None: ...

class ListMediatorDomainStateRequest(_message.Message):
    __slots__ = ("base_query", "filter_domain", "filter_mediator")
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    FILTER_MEDIATOR_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    filter_domain: str
    filter_mediator: str
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ..., filter_domain: _Optional[str] = ..., filter_mediator: _Optional[str] = ...) -> None: ...

class ListMediatorDomainStateResult(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("context", "item")
        CONTEXT_FIELD_NUMBER: _ClassVar[int]
        ITEM_FIELD_NUMBER: _ClassVar[int]
        context: BaseResult
        item: _topology_pb2.MediatorDomainState
        def __init__(self, context: _Optional[_Union[BaseResult, _Mapping]] = ..., item: _Optional[_Union[_topology_pb2.MediatorDomainState, _Mapping]] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListMediatorDomainStateResult.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListMediatorDomainStateResult.Result, _Mapping]]] = ...) -> None: ...

class ListAllRequest(_message.Message):
    __slots__ = ("base_query",)
    BASE_QUERY_FIELD_NUMBER: _ClassVar[int]
    base_query: BaseQuery
    def __init__(self, base_query: _Optional[_Union[BaseQuery, _Mapping]] = ...) -> None: ...

class ListAllResponse(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: _topology_ext_pb2.TopologyTransactions
    def __init__(self, result: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/connection/v30/api_info.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/connection/v30/api_info.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5com/digitalasset/canton/connection/v30/api_info.proto\x12&com.digitalasset.canton.connection.v30\"\x13\n\x11GetApiInfoRequest\"(\n\x12GetApiInfoResponse\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name2\x96\x01\n\x0e\x41piInfoService\x12\x83\x01\n\nGetApiInfo\x12\x39.com.digitalasset.canton.connection.v30.GetApiInfoRequest\x1a:.com.digitalasset.canton.connection.v30.GetApiInfoResponseBWZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/connection/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.connection.v30.api_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/connection/v30'
  _globals['_GETAPIINFOREQUEST']._serialized_start=97
  _globals['_GETAPIINFOREQUEST']._serialized_end=116
  _globals['_GETAPIINFORESPONSE']._serialized_start=118
  _globals['_GETAPIINFORESPONSE']._serialized_end=158
  _globals['_APIINFOSERVICE']._serialized_start=161
  _globals['_APIINFOSERVICE']._serialized_end=311
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencing_pb2 import DynamicDomainParameters, StaticDomainParameters
from .common_pb2 import GlobalKey, Metadata, SerializableContract
from .merkle_pb2 import BlindableNode, GenTransactionTree, MerkleSeq, MerkleSeqElement
from .mediator_pb2 import InformeeTree, MalformedMediatorRequestResult, MediatorReject, ParticipantReject, TransactionResultMessage, TransferResult, Verdict
from .mediator_response_pb2 import LocalReject, LocalVerdict, MediatorResponse
from .participant_transaction_pb2 import ActionDescription, CreatedContract, EncryptedViewMessage, FullInformeeTree, Informee, InformeeMessage, InputContract, LightTransactionViewTree, ParticipantRandomnessLookup, ResolvedKey, SubmitterMetadata, ViewCommonData, ViewNode, ViewParticipantMessage
from .participant_transfer_pb2 import TransferInCommonData, TransferInMediatorMessage, TransferInView, TransferOutCommonData, TransferOutMediatorMessage, TransferOutView, TransferViewTree
from .topology_pb2 import DomainGovernanceTransaction, DomainParametersChange, DomainTopologyTransactionMessage, RegisterTopologyTransactionResponse, TopologyStateUpdate, TopologyTransaction
from .synchronization_pb2 import EnvelopeContent

__all__ = [
    "ActionDescription",
    "BlindableNode",
    "CreatedContract",
    "DomainGovernanceTransaction",
    "DomainParametersChange",
    "DomainTopologyTransactionMessage",
    "DynamicDomainParameters",
    "EncryptedViewMessage",
    "EnvelopeContent",
    "FullInformeeTree",
    "GenTransactionTree",
    "GlobalKey",
    "Informee",
    "InformeeMessage",
    "InformeeTree",
    "InputContract",
    "LightTransactionViewTree",
    "LocalReject",
    "LocalVerdict",
    "MalformedMediatorRequestResult",
    "MediatorReject",
    "MediatorResponse",
    "MerkleSeq",
    "MerkleSeqElement",
    "Metadata",
    "ParticipantRandomnessLookup",
    "ParticipantReject",
    "RegisterTopologyTransactionResponse",
    "ResolvedKey",
    "SerializableContract",
    "StaticDomainParameters",
    "SubmitterMetadata",
    "TopologyStateUpdate",
    "TopologyTransaction",
    "TransactionResultMessage",
    "TransferInCommonData",
    "TransferInMediatorMessage",
    "TransferInView",
    "TransferOutCommonData",
    "TransferOutMediatorMessage",
    "TransferOutView",
    "TransferResult",
    "TransferViewTree",
    "Verdict",
    "ViewCommonData",
    "ViewNode",
    "ViewParticipantMessage",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/checkpoint.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/checkpoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'com/daml/ledger/api/v2/checkpoint.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"a\n\nCheckpoint\x12;\n\x0brecord_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12\x16\n\x06offset\x18\x02 \x01(\tR\x06offsetB\x8e\x01\n\x16\x63om.daml.ledger.api.v2B\x14\x43heckpointOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.checkpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\024CheckpointOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_CHECKPOINT']._serialized_start=100
  _globals['_CHECKPOINT']._serialized_end=197
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v30 import crypto_pb2 as _crypto_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AggregatedSignaturesOfSender(_message.Message):
    __slots__ = ("signatures_by_envelope",)
    class SignaturesForEnvelope(_message.Message):
        __slots__ = ("signatures",)
        SIGNATURES_FIELD_NUMBER: _ClassVar[int]
        signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
        def __init__(self, signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ...) -> None: ...
    SIGNATURES_BY_ENVELOPE_FIELD_NUMBER: _ClassVar[int]
    signatures_by_envelope: _containers.RepeatedCompositeFieldContainer[AggregatedSignaturesOfSender.SignaturesForEnvelope]
    def __init__(self, signatures_by_envelope: _Optional[_Iterable[_Union[AggregatedSignaturesOfSender.SignaturesForEnvelope, _Mapping]]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/transaction_filter.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/transaction_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/com/daml/ledger/api/v1/transaction_filter.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\"com/daml/ledger/api/v1/value.proto\"\xe0\x01\n\x11TransactionFilter\x12g\n\x10\x66ilters_by_party\x18\x01 \x03(\x0b\x32=.com.daml.ledger.api.v1.TransactionFilter.FiltersByPartyEntryR\x0e\x66iltersByParty\x1a\x62\n\x13\x46iltersByPartyEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v1.FiltersR\x05value:\x02\x38\x01\"Q\n\x07\x46ilters\x12\x46\n\tinclusive\x18\x01 \x01(\x0b\x32(.com.daml.ledger.api.v1.InclusiveFiltersR\tinclusive\"\x86\x02\n\x10InclusiveFilters\x12I\n\x0ctemplate_ids\x18\x01 \x03(\x0b\x32\".com.daml.ledger.api.v1.IdentifierB\x02\x18\x01R\x0btemplateIds\x12T\n\x11interface_filters\x18\x02 \x03(\x0b\x32\'.com.daml.ledger.api.v1.InterfaceFilterR\x10interfaceFilters\x12Q\n\x10template_filters\x18\x03 \x03(\x0b\x32&.com.daml.ledger.api.v1.TemplateFilterR\x0ftemplateFilters\"\xd1\x01\n\x0fInterfaceFilter\x12\x45\n\x0cinterface_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\x0binterfaceId\x12\x34\n\x16include_interface_view\x18\x02 \x01(\x08R\x14includeInterfaceView\x12;\n\x1ainclude_created_event_blob\x18\x04 \x01(\x08R\x17includeCreatedEventBlobJ\x04\x08\x03\x10\x04\"\x92\x01\n\x0eTemplateFilter\x12\x43\n\x0btemplate_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v1.IdentifierR\ntemplateId\x12;\n\x1ainclude_created_event_blob\x18\x02 \x01(\x08R\x17includeCreatedEventBlobB\x95\x01\n\x16\x63om.daml.ledger.api.v1B\x1bTransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.transaction_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v1B\033TransactionFilterOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1'
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._loaded_options = None
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_options = b'8\001'
  _globals['_INCLUSIVEFILTERS'].fields_by_name['template_ids']._loaded_options = None
  _globals['_INCLUSIVEFILTERS'].fields_by_name['template_ids']._serialized_options = b'\030\001'
  _globals['_TRANSACTIONFILTER']._serialized_start=112
  _globals['_TRANSACTIONFILTER']._serialized_end=336
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_start=238
  _globals['_TRANSACTIONFILTER_FILTERSBYPARTYENTRY']._serialized_end=336
  _globals['_FILTERS']._serialized_start=338
  _globals['_FILTERS']._serialized_end=419
  _globals['_INCLUSIVEFILTERS']._serialized_start=422
  _globals['_INCLUSIVEFILTERS']._serialized_end=684
  _globals['_INTERFACEFILTER']._serialized_start=687
  _globals['_INTERFACEFILTER']._serialized_end=896
  _globals['_TEMPLATEFILTER']._serialized_start=899
  _globals['_TEMPLATEFILTER']._serialized_end=1045
# @@protoc_insertion_point(module_scope)
